@@ -164,7 +164,7 @@ class Mundi:
             ax.legend(handles=Q.plot_handles, loc='upper right')
             plt.show()
 
-    def q(self, fn, progressbar=False):
+    def q(self, fn, progressbar=False, n=0):
         # make iterator unique by geometry
         unique_iterator = self.main.dataframe.drop_duplicates(subset=['geometry'])
 
@@ -182,9 +182,13 @@ class Mundi:
             Q = MundiQ(window, self.mapdata)
             res = fn(Q)
 
+            # if res is None, skip
+            if res is None:
+                continue
+
             # coerce to tuple
             if not isinstance(res, dict):
-                raise TypeError('function passed to mundi.q() must return dict but instead got %s' % type(res).__name__)
+                raise TypeError('function passed to mundi.q() must return dict or None but instead got %s' % type(res).__name__)
 
             if res_keys is None:
                 res_keys = res.keys()
@@ -199,4 +203,8 @@ class Mundi:
                 res_outs[key].append(val)
             res_outs['geometry'].append(original_shape)
 
+            # check n
+            if n > 0 and len(res_outs['geometry']) == n:
+                break
+
         return gpd.GeoDataFrame(res_outs, crs='EPSG:4326', geometry='geometry')
